@@ -6,7 +6,7 @@
 # URL: <https://github.com/Yzstr/CRTK>
 # For license information, see LICENSE
 
-# import sha3
+import os
 
 from CRTK.mapping import opcode_mapping, push_mapping
 
@@ -269,3 +269,35 @@ def split_bytecode(bytecode):
         arguments.append(aug)
 
     return deployment_bytecode, runtime_bytecode, bzzr, arguments
+
+
+def function_to_signature(function_name):
+    '''
+    Convert function definition to function signature.
+
+    input: string
+    output: string
+    '''
+    import sha3
+    signature = sha3.keccak_256(str(function_name).encode('utf-8')).hexdigest().lower()[:8]
+    return signature
+
+def signature_to_function(function_signature):
+    '''
+    Convert function signature to function definition by reverse query. See https://github.com/Yzstr/Function-Signatures.
+
+    input: string
+    output: list
+
+    There might be several query results if hash collision encountered and also might be no result due to data vacancy.
+    '''
+    dir_list = os.listdir('../')
+    if not 'Function-Signatures' in dir_list:
+        import subprocess
+        subprocess.run(['git', 'clone', 'https://github.com/yzstr/Function-Signatures.git', '../Function-Signatures'])
+    
+    import csv
+    with open('../Function-Signatures/Function-Signature.csv','r') as f:
+        reader = csv.reader(f)
+        res = [line[0] for line in reader if line[1] == function_signature]
+    return res
\ No newline at end of file
